import {RootState} from '@redux/store';
import {ReactNode} from 'react';
import {
  AccessibilityRole,
  GestureResponderEvent,
  StyleProp,
  TouchableOpacity,
  ViewStyle,
} from 'react-native';
import {useSelector} from 'react-redux';

interface CustomTouchableProps {
  children?: ReactNode;
  onPress?: () => void;
  onLongPress?: ((event: GestureResponderEvent) => void) | undefined;
  style?: StyleProp<ViewStyle>;
  disabled?: boolean;
  accessibilityRole?: AccessibilityRole | undefined;
}

export function MyTouchableOpacity({
  children,
  onPress,
  onLongPress,
  style,
  disabled,
  accessibilityRole,
}: CustomTouchableProps) {
  const currentTheme = useSelector(
    (state: RootState) => state.nonSaveVariables.theme.opacity,
  );

  return (
    <TouchableOpacity
      disabled={disabled}
      onPress={onPress}
      onLongPress={onLongPress}
      style={style}
      activeOpacity={currentTheme[80]}
      accessibilityRole={accessibilityRole}>
      {children}
    </TouchableOpacity>
  );
}
