import React from 'react';
import {Animated} from 'react-native';

import colors from '@configs/colors';
import {View, Image, Text, StyleSheet} from 'react-native';
import {PA_Point} from './cluster/getData';
import {store} from '@redux/store';

import {
  Avatar,
  AvatarBadge,
  AvatarFallbackText,
  AvatarGroup,
  AvatarImage,
} from '@gluestack-ui/themed';

import tate from '@assets/tate.jpg';

export function EventMarker(props: {marker: PA_Point}) {
  const marker = props.marker;
  const colors = store.getState().nonSaveVariables.theme.colors;

  const fadeAnim = React.useRef(new Animated.Value(0)).current;
  const fadeAnim2 = React.useRef(new Animated.Value(0.9)).current;

  React.useEffect(() => {
    Animated.timing(fadeAnim, {
      toValue: 1,
      duration: 300,
      useNativeDriver: true,
    }).start();
  }, [fadeAnim]);

  React.useEffect(() => {
    Animated.timing(fadeAnim2, {
      toValue: 1,
      duration: 500,
      useNativeDriver: true,
    }).start();
  }, [fadeAnim2]);

  const avatars = [
    {
      src: 'https://image.stern.de/32707724/t/o5/v2/w1440/r1.7778/-/andrew-tate.jpg',
      alt: 'Sandeep Srivastva',
      color: '$emerald600',
    },
    {
      src: 'https://image.stern.de/32707724/t/o5/v2/w1440/r1.7778/-/andrew-tate.jpg',
      alt: 'Arjun Kapoor',
      color: '$cyan600',
    },
    {
      src: 'https://image.stern.de/32707724/t/o5/v2/w1440/r1.7778/-/andrew-tate.jpg',
      alt: 'Ritik Sharma ',
      color: '$indigo600',
    },
    {
      src: 'https://image.stern.de/32707724/t/o5/v2/w1440/r1.7778/-/andrew-tate.jpg',
      alt: 'Akhil Sharma',
      color: '$gray600',
    },
    {
      src: 'https://image.stern.de/32707724/t/o5/v2/w1440/r1.7778/-/andrew-tate.jpg',
      alt: 'Rahul Sharma ',
      color: '$red400',
    },
  ];
  const extraAvatars = avatars.slice(3);
  const remainingCount = extraAvatars.length;

  return (
    <Animated.View
      style={{
        ...styles.marker,
        backgroundColor: colors.backgroundDark400,
        opacity: fadeAnim,
        transform: [{scale: fadeAnim2}],
      }}>
      <AvatarGroup>
        {avatars.slice(0, 3).map((avatar, index) => {
          return (
            <Avatar
              key={index}
              size="sm"
              borderColor="$black"
              borderWidth="$2"
              bg={avatar.color}
              sx={{
                _dark: {
                  borderColor: '$black',
                },
              }}>
              <AvatarFallbackText>{avatar.alt}</AvatarFallbackText>
            </Avatar>
          );
        })}
        <Avatar
          size="sm"
          borderColor="$white"
          borderWidth="$2"
          bg="$gray600"
          sx={{
            _dark: {
              borderColor: '$black',
            },
          }}>
          <AvatarFallbackText>{'+ ' + remainingCount + ''}</AvatarFallbackText>
        </Avatar>
      </AvatarGroup>
      <Image
        source={tate}
        style={{width: 100, height: 100, alignSelf: 'center'}}
      />

      <Text style={styles.markerText}>{marker.type}</Text>
    </Animated.View>
  );
}

const styles = StyleSheet.create({
  marker: {
    padding: 5,
    borderRadius: 5,
  },
  markerText: {
    color: 'white',
    fontWeight: 'bold',
  },
});
